<?php
/**
 * @package   DPBexio
 * @copyright Copyright (C) 2022 Digital Peak GmbH. <https://www.digital-peak.com>
 * @license   https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 */

namespace DigitalPeak\Plugin\Content\DPBexio\Extension;

use DigitalPeak\Library\DPBexio\Bexio\API;
use Joomla\CMS\Application\CMSApplicationInterface;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\User\UserFactoryInterface;
use Joomla\Event\DispatcherInterface;
use Joomla\Event\Event;
use Joomla\Event\SubscriberInterface;

final class DPBexio extends CMSPlugin implements SubscriberInterface
{
	public static function getSubscribedEvents(): array
	{
		return ['onContentAfterDisplay' => 'afterDisplay'];
	}

	protected $autoloadLanguage = true;

	/** @var CMSApplicationInterface $app */
	protected $app;
	private $api;
	private $userFactory;

	public function __construct(API $api, UserFactoryInterface $userFactory, DispatcherInterface $subject, $config = [])
	{
		parent::__construct($subject, $config);

		$this->api         = $api;
		$this->userFactory = $userFactory;
	}

	public function afterDisplay(Event $e)
	{
		$context = $e->getArgument(0);

		// Check if we can render contacts
		if ($context !== 'com_contact.contact') {
			return;
		}

		$contact = $e->getArgument(1);

		$email = $contact->email_raw ?? $contact->email_to;

		if (!$email && $contact->user_id) {
			$email = $this->userFactory->loadUserById($contact->user_id)->email;
		}

		if (!$email) {
			return;
		}

		$contacts = $this->api->callBexioAPI(
			'/2.0/contact/search',
			[['field' => 'mail', 'value' => $email, 'criteria' => '=']],
			$this->params,
			'post'
		)->data;

		if(!$contacts) {
			return;
		}

		// The invoice data
		$currencies = [];
		foreach ($this->api->callBexioAPI('/3.0/currencies', [], $this->params, )->data as $currency) {
			$currencies[$currency->id] = $currency->name;
		}

		$invoices = $this->api->callBexioAPI(
			'/2.0/kb_invoice/search',
			[['field' => 'contact_id', 'value' => $contacts[0]->id, 'criteria' => '=']],
			$this->params,
			'post'
		)->data;

		ob_start();
		require PluginHelper::getLayoutPath($this->_type, $this->_name, 'invoice/contact');

		$e->setArgument('result', array_merge($e->getArgument('result'), [ob_get_clean()]));
	}
}
